Action

Enum Action 

#[non_exhaustive]
pub enum Action { Notify, NotifyInApp, SetTweak(Tweak), }
This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client.

See the spec for details.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Notify

Causes matching events to generate a notification (both in-app and remote / push).



NotifyInApp

Available on crate feature unstable-msc3768 only.

Causes matching events to generate an in-app notification but no remote / push notification.



SetTweak(Tweak)

Sets an entry in the ‘tweaks’ dictionary sent to the push gateway.

Implementations

Source

impl Action

pub fn new(data: CustomActionData) -> Result<Action, Error>

Available on crate feature events only.

Creates a new Action.

Prefer to use the public variants of Action where possible; this constructor is meant be used for unsupported actions only and does not allow setting arbitrary data for supported ones.

Errors

Returns an error if the action type is known and deserialization of data to the corresponding variant fails.

pub fn is_highlight(&self) -> bool

Available on crate feature events only.

Whether this action is an Action::SetTweak(Tweak::Highlight(true)).

pub fn should_notify(&self) -> bool

Available on crate feature events only.

Whether this action should trigger a notification (either in-app or remote / push).

pub fn should_notify_remote(&self) -> bool

Available on crate features events and unstable-msc3768 only.

Whether this action should trigger a remote / push notification.

pub fn sound(&self) -> Option<&SoundTweakValue>

Available on crate feature events only.

The sound that should be played with this action, if any.

pub fn custom_data(&self) -> Option<&CustomActionData>

Available on crate feature events only.

Access the data if this is a custom action.