#[non_exhaustive]pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
PostContent(ConditionalPushRule),
Room(SimplePushRule<OwnedRoomId>),
Sender(SimplePushRule<OwnedUserId>),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Override(ConditionalPushRule)
Rules that override all other kinds.
Content(PatternedPushRule)
Content-specific rules.
PostContent(ConditionalPushRule)
unstable-msc4306 only.Post-content specific rules.
Room(SimplePushRule<OwnedRoomId>)
Room-specific rules.
Sender(SimplePushRule<OwnedUserId>)
Sender-specific rules.
Underride(ConditionalPushRule)
Lowest priority rules.
Implementations
Sourceimpl AnyPushRule
impl AnyPushRule
Sourcepub fn as_ref(&self) -> AnyPushRuleRef<'_>
Available on crate feature events only.
pub fn as_ref(&self) -> AnyPushRuleRef<'_>
events only.Convert AnyPushRule to AnyPushRuleRef.
Sourcepub fn enabled(&self) -> bool
Available on crate feature events only.
pub fn enabled(&self) -> bool
events only.Get the enabled flag of the push rule.
Sourcepub fn actions(&self) -> &[Action]
Available on crate feature events only.
pub fn actions(&self) -> &[Action]
events only.Get the actions of the push rule.
Sourcepub fn triggers_highlight(&self) -> bool
Available on crate feature events only.
pub fn triggers_highlight(&self) -> bool
events only.Whether an event that matches the push rule should be highlighted.
Sourcepub fn triggers_notification(&self) -> bool
Available on crate feature events only.
pub fn triggers_notification(&self) -> bool
events only.Whether an event that matches the push rule should trigger a notification (either in-app or remote / push).
Sourcepub fn triggers_remote_notification(&self) -> bool
Available on crate features events and unstable-msc3768 only.
pub fn triggers_remote_notification(&self) -> bool
events and unstable-msc3768 only.Whether an event that matches the push rule should trigger a remote notification.
Sourcepub fn triggers_sound(&self) -> Option<&str>
Available on crate feature events only.
pub fn triggers_sound(&self) -> Option<&str>
events only.The sound that should be played when an event matches the push rule, if any.
Sourcepub fn rule_id(&self) -> &str
Available on crate feature events only.
pub fn rule_id(&self) -> &str
events only.Get the rule_id of the push rule.
Sourcepub fn is_server_default(&self) -> bool
Available on crate feature events only.
pub fn is_server_default(&self) -> bool
events only.Whether the push rule is a server-default rule.
Sourcepub async fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx,
) -> bool
Available on crate feature events only.
pub async fn applies( &self, event: &FlattenedJson, context: &PushConditionRoomCtx, ) -> bool
events only.Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.