pub enum HighlightTweakValue {
Yes,
No,
}Expand description
Whether or not a message should be highlighted in the UI.
This will normally take the form of presenting the message in a different color and/or style. The UI might also be adjusted to draw particular attention to the room in which the event occurred.
Variants