#[non_exhaustive]pub struct EventMatchConditionData {
pub key: String,
pub pattern: String,
}Expand description
Data for the event_match PushCondition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: StringThe dot-separated path of the property of the event to match.
pattern: StringThe glob-style pattern to match against.
Patterns with no special glob characters should be treated as having asterisks prepended and appended when testing the condition.
Implementations
Sourceimpl EventMatchConditionData
impl EventMatchConditionData
Sourcepub fn new(key: String, pattern: String) -> EventMatchConditionData
Available on crate feature events only.
pub fn new(key: String, pattern: String) -> EventMatchConditionData
events only.Construct a new EventMatchConditionData with the given path and pattern.